@@ -36,6 +36,7 @@ from urllib.parse import urlparse
 from zipfile import BadZipFile, ZipFile
 from csv import writer
 from datetime import datetime
+import pandas as pd
 from ._constants import *
 
 logger = logging.getLogger(__name__)
@@ -93,25 +94,23 @@ class IndexHandler:
         self._base_index_path = self.root_path / "index" / "base_index"
         self._file_num_index_path = self.root_path / "index" / "file_num_index"
 
-    def _get_base_index_path(self, cik10):
-        return self._base_index_path / cik10 +".csv"
-    
-    def _get_file_num_index_path(self, cik10):
-        return self._file_num_index_path / cik10 +".json"
 
-    def _prepare_root_path(self, path, create_folder=True):
-        if not isinstance(path, Path) and isinstance(path, str):
-            path = Path(path)
-        if isinstance(path, Path):
-            if create_folder is True:
-                if not path.exists():
-                    path.mkdir(parents=True)
-            elif create_folder is False:
-                if not path.exists():
-                    raise OSError("root_path doesnt exist")
-            return path
-        else:
-            raise ValueError(f"root_path is expect to be of type str or pathlib.Path, got type: {type(path)}")
+    
+    def get_local_filings_by_form_type(self, cik: str, form_type: str):
+        '''gets all the index entries of form_type and cik.
+        
+        Returns:
+            dict with keys: form_type, file_number, file_path, filing_date
+        '''
+        index_path = self._get_base_index_path(cik)
+        df = pd.read_csv(index_path)
+        df = df[df["form_type"] == form_type]
+        print(df)
+        for row in df.iloc:       
+            df.loc[row.name, ("file_path", )] = self._relative_to_absolute_filing_path(row["file_path"])
+            df.loc[row.name, ("accession_number", )] = self._get_accession_number_from_relative_path(row["file_path"])
+        return df.to_dict("records")
+    
 
     def get_newer_filings_meta(self, cik, after: str, tracked_filings: set = None):
         '''check a submission file and get filings newer than 'after'.
@@ -232,6 +231,36 @@ class IndexHandler:
         logger.info((f"completed check of indexes \n"
                      f"base_index: {base_remove_count} entries removed \n"
                      f"num_index: {num_remove_count} entries removed \n"))
+
+    def _get_base_index_path(self, cik10):
+        return self._base_index_path / cik10 +".csv"
+    
+    def _get_file_num_index_path(self, cik10):
+        return self._file_num_index_path / cik10 +".json"
+
+    def _prepare_root_path(self, path, create_folder=True):
+        if not isinstance(path, Path) and isinstance(path, str):
+            path = Path(path)
+        if isinstance(path, Path):
+            if create_folder is True:
+                if not path.exists():
+                    path.mkdir(parents=True)
+            elif create_folder is False:
+                if not path.exists():
+                    raise OSError("root_path doesnt exist")
+            return path
+        else:
+            raise ValueError(f"root_path is expect to be of type str or pathlib.Path, got type: {type(path)}")
+
+    def _get_accession_number_from_relative_path(self, rel_path):
+        if isinstance(rel_path, str):
+            return str(Path(rel_path).parent.name).replace("-", "")
+        if isinstance(rel_path, Path):
+            return str(rel_path.parent.name).replace("-", "")
+        raise TypeError(f"rel_path should be of type str or pathlib.Path, got: {type(rel_path)}")
+    
+    def _relative_to_absolute_filing_path(self, rel_path):
+        return urljoin(self.root_path, rel_path)
     
     
     def _create_indexes(self, cik, form_type, accn, file_name, file_num, filing_date):
@@ -982,7 +1011,7 @@ class Downloader:
         accession_number, filing_details_filename = hit["_id"].split(":", 1)
         accession_number_no_dash = accession_number.replace("-", "", 2)
         cik = hit["_source"]["ciks"][-1]
-        film_num = hit["_source"]["film_num"]
+        file_num = hit["_source"]["file_num"]
         submission_base_url = urljoin(urljoin(EDGAR_ARCHIVES_BASE_URL, cik),(accession_number_no_dash))
         xsl = hit["_source"]["xsl"] if hit["_source"]["xsl"] else None
         filing_date = hit["_source"]["file_date"]
@@ -993,7 +1022,7 @@ class Downloader:
             "base_url": submission_base_url,
             "main_file_name": filing_details_filename,
             "xsl": xsl,
-            "file_num": film_num,
+            "file_num": file_num,
             "filing_date": filing_date}
    
 
@@ -1110,4 +1139,4 @@ class Downloader:
         adapter = requests.adapters.HTTPAdapter(max_retries=r) 
         session.mount("http://", adapter)
         session.mount("https://", adapter)
-        return session
\ No newline at end of file
+        return session
